package com.zigzah.utils
{
	import flash.events.Event;
	import flash.events.EventDispatcher;
	import flash.filesystem.File;
	import flash.filesystem.FileMode;
	import flash.filesystem.FileStream;
	import flash.net.FileFilter;
	import flash.utils.ByteArray;
	
	/**Dispatched when the user selects a file from the fileSystem, 
	 * and the bytearray from the file is ready.*/
	[Event(name="bytesloaded", type="com.zigzah.utils.LoadFileEvent")]
	
	/** A utility class to get files easily from the filesystem  */
	public class FileLoader extends EventDispatcher
	{
		private var file :File
		private var filter:FileFilter
		
		/**The title of the open dialog window*/
		public var openDialog : String = "Open File";
		
		
		/**Creates a new FileLoader object, with the specified filefilter and 
		 * default path, in the open dialog
		 * @param filter the filefilter object that will be used to browse for files in the filesystem.
		 * @param fileID the id that PathSaver will to get a file.*/
		public function FileLoader(filter : FileFilter , fileID : String = "$defaultSaveFile")
		{
			file = PathSaver.getFile(fileID);
			this.filter = filter;
			file.addEventListener(Event.SELECT, makeBytes);
		}
		
		/** Opens the browse dialog. When the user chooses a file, a 
		 * LoadFileEvent will be dispatched, and it will contain the bytearray
		 * retrieved by the file.
		 * @see LoadFileEvent*/
		public function getBytes ():void
		{
			file.browseForOpen(openDialog ,[filter]);
		}
		
		/**Returns a ByteArray, for the LoadFileEvent.*/
		private function makeBytes (event:Event) :void
		{
			var fs:FileStream = new FileStream ();
			fs.open(event.target as File, FileMode.READ);
			var ba:ByteArray = new ByteArray ();
			fs.readBytes(ba, 0, fs.bytesAvailable);
			fs.close();
			var ev:LoadFileEvent = new LoadFileEvent();
			ev.bytes = ba;
			ev.fileName = file.name;
			this.dispatchEvent (ev);
		}

	}
}