package com.zigzah.utils
{
	import flash.events.Event;
	import flash.filesystem.File;
	import flash.net.SharedObject;
	
	/**Class to manage the file paths in a more usable way.*/
	public class PathSaver
	{
		
		private static var so:SharedObject;

		/** Returns a file from the location it was saved the last time.
		 * @param id The id of the given file.
		 * @param returnName if true, the function returns name of the file, else, it returns the folder.
		 * @param newName if returnName is set to false, the new name of the file.
		 * @return A File object, with the path it had the last time it was saved. */
				
		public static function getFile (id:String , returnName:Boolean = false , newName:String = ""):File
		{
			/*Obtenemos el SharedObject, 
			y sacamos la ruta del archivo y la del directorio.*/
			so = SharedObject.getLocal(id + "$file");
			var path: String = so.data.path;
			var parent: String = so.data.parent;
			var file:File = new File ();
			
			/*Devolvemos un nuevo archivo según si existía el so,
			 y según los parámetros.*/
			if (path && parent)
			{
				if (returnName)
				{
					file = file.resolvePath(path);
				}else if (newName != "")
				{
					file = file.resolvePath(parent).resolvePath(newName);
				}else {
					file = file.resolvePath(parent)
				}
			} else
			{
				file = File.desktopDirectory.resolvePath(newName);
			}
			
			/*Indicamos que cada vez que el archivo se guarde o abra, 
			su nueva ruta quede almacenada en el so.*/
			file.addEventListener(Event.SELECT, savePath);
			
			return file;
		}
		
		
		/** This function saves the file path in a sharedObject. */
		private static function savePath (event:Event) :void
		{
			var file:File = event.target as File;
			so.data.path = file.nativePath;
			so.data.parent = file.parent.nativePath;
			so.flush();
		}

	}
}